import React, { useState, useEffect, useRef } from 'react';
import { AlertCircle, Volume2, VolumeX, Play, Pause, SkipBack, SkipForward, Repeat, Shuffle } from 'lucide-react';
import { Alert, AlertDescription } from '@/components/ui/alert';

const MediaPlayerUI = ({
  type,
  mediaRef,
  currentTrack,
  playlist,
  isPlaying,
  currentTime,
  duration,
  volume,
  isMuted,
  repeat,
  shuffle,
  error,
  isLoading,
  handlers
}) => {
  const [showVolumeSlider, setShowVolumeSlider] = useState(false);
  const [isDraggingTime, setIsDraggingTime] = useState(false);
  const [lastVolume, setLastVolume] = useState(volume);
  const [buffered, setBuffered] = useState(0);
  const timeSliderRef = useRef(null);
  const volumeSliderRef = useRef(null);

  const formatTime = (seconds) => {
    if (!seconds) return '0:00';
    const mins = Math.floor(seconds / 60);
    const secs = Math.floor(seconds % 60);
    return `${mins}:${secs.toString().padStart(2, '0')}`;
  };

  // Gestion du buffer
  useEffect(() => {
    if (!mediaRef.current) return;
    
    const updateBuffer = () => {
      if (mediaRef.current.buffered.length > 0) {
        setBuffered(mediaRef.current.buffered.end(mediaRef.current.buffered.length - 1));
      }
    };

    mediaRef.current.addEventListener('progress', updateBuffer);
    return () => mediaRef.current?.removeEventListener('progress', updateBuffer);
  }, [mediaRef]);

  // Double-clic pour plein écran sur la vidéo
  useEffect(() => {
    if (type !== 'video' || !mediaRef.current) return;
    
    const handleDblClick = () => {
      if (document.fullscreenElement) {
        document.exitFullscreen();
      } else {
        mediaRef.current.requestFullscreen();
      }
    };

    mediaRef.current.addEventListener('dblclick', handleDblClick);
    return () => mediaRef.current?.removeEventListener('dblclick', handleDblClick);
  }, [type, mediaRef]);

  if (error) {
    return (
      <Alert variant="destructive" className="m-4">
        <AlertCircle className="h-4 w-4" />
        <AlertDescription>
          {error}
          <button 
            onClick={() => handlers.setError(null)}
            className="ml-2 text-sm underline hover:no-underline"
          >
            Réessayer
          </button>
        </AlertDescription>
      </Alert>
    );
  }

  return (
    <div className="flex flex-col h-full bg-white dark:bg-player-bg">
      {type === 'video' && (
        <div className="relative aspect-video bg-black">
          <video
            ref={mediaRef}
            className="w-full h-full"
            onTimeUpdate={handlers.handleTimeUpdate}
            onEnded={handlers.playNext}
          />
          {isLoading && (
            <div className="absolute inset-0 flex items-center justify-center bg-black/50">
              <div className="w-12 h-12 border-4 border-t-blue-500 border-b-blue-500 rounded-full animate-spin" />
            </div>
          )}
        </div>
      )}
      
      {type === 'audio' && (
        <audio
          ref={mediaRef}
          onTimeUpdate={handlers.handleTimeUpdate}
          onEnded={handlers.playNext}
          className="hidden"
        />
      )}

      <div className="p-4 space-y-4 flex-shrink-0 bg-gray-50 dark:bg-player-surface">
        <div className="text-lg font-medium truncate dark:text-white">
          {currentTrack.name || 'Aucune piste sélectionnée'}
        </div>

        <div className="space-y-2">
          {/* Barre de progression avec buffer */}
          <div className="relative h-1 group">
            <div className="absolute inset-0 bg-gray-200 dark:bg-gray-700 rounded-full">
              <div 
                className="absolute h-full bg-gray-400 dark:bg-gray-600 rounded-full"
                style={{ width: `${(buffered / duration) * 100}%` }}
              />
              <div 
                className="absolute h-full bg-blue-500 rounded-full"
                style={{ width: `${(currentTime / duration) * 100}%` }}
              />
            </div>
            <input
              ref={timeSliderRef}
              type="range"
              min="0"
              max="100"
              value={(currentTime / duration) * 100 || 0}
              onChange={(e) => {
                const value = parseFloat(e.target.value);
                handlers.handleSeek(value);
              }}
              onMouseDown={() => setIsDraggingTime(true)}
              onMouseUp={() => setIsDraggingTime(false)}
              className="absolute inset-0 w-full opacity-0 cursor-pointer"
            />
          </div>

          <div className="flex justify-between text-sm text-gray-600 dark:text-gray-400">
            <span>{formatTime(currentTime)}</span>
            <span>{formatTime(duration)}</span>
          </div>
        </div>

        <div className="flex items-center justify-between">
          <div className="flex items-center space-x-4">
            <button
              onClick={() => handlers.setRepeat(!repeat)}
              className={`p-2 rounded-full hover:bg-gray-200 dark:hover:bg-gray-700 
                ${repeat ? 'text-blue-500' : 'text-gray-700 dark:text-gray-300'}`}
              title="Répéter"
            >
              <Repeat className="w-5 h-5" />
            </button>

            <button
              onClick={handlers.playPrevious}
              className="p-2 rounded-full hover:bg-gray-200 dark:hover:bg-gray-700 text-gray-700 dark:text-gray-300"
              title="Précédent"
            >
              <SkipBack className="w-5 h-5" />
            </button>

            <button
              onClick={handlers.handlePlayPause}
              className="p-3 rounded-full bg-blue-500 hover:bg-blue-600 text-white"
              title={isPlaying ? 'Pause' : 'Lecture'}
            >
              {isPlaying ? <Pause className="w-6 h-6" /> : <Play className="w-6 h-6" />}
            </button>

            <button
              onClick={handlers.playNext}
              className="p-2 rounded-full hover:bg-gray-200 dark:hover:bg-gray-700 text-gray-700 dark:text-gray-300"
              title="Suivant"
            >
              <SkipForward className="w-5 h-5" />
            </button>

            <button
              onClick={() => handlers.setShuffle(!shuffle)}
              className={`p-2 rounded-full hover:bg-gray-200 dark:hover:bg-gray-700
                ${shuffle ? 'text-blue-500' : 'text-gray-700 dark:text-gray-300'}`}
              title="Lecture aléatoire"
            >
              <Shuffle className="w-5 h-5" />
            </button>
          </div>

          <div 
            className="relative flex items-center space-x-2"
            onMouseEnter={() => setShowVolumeSlider(true)}
            onMouseLeave={() => setShowVolumeSlider(false)}
          >
            <button
              onClick={() => {
                if (!isMuted) {
                  setLastVolume(volume);
                  handlers.handleVolumeChange(0);
                } else {
                  handlers.handleVolumeChange(lastVolume * 100);
                }
                handlers.toggleMute();
              }}
              className="p-2 hover:bg-gray-200 dark:hover:bg-gray-700 rounded-full text-gray-700 dark:text-gray-300"
              title={isMuted ? "Activer le son" : "Couper le son"}
            >
              {isMuted ? <VolumeX className="w-5 h-5" /> : <Volume2 className="w-5 h-5" />}
            </button>

            <div className={`absolute left-full ml-2 w-24 bg-white dark:bg-gray-800 p-2 rounded-lg shadow-lg transition-opacity
              ${showVolumeSlider ? 'opacity-100' : 'opacity-0 pointer-events-none'}`}>
              <input
                ref={volumeSliderRef}
                type="range"
                min="0"
                max="100"
                value={isMuted ? 0 : volume * 100}
                onChange={(e) => handlers.handleVolumeChange(parseFloat(e.target.value))}
                className="w-full"
                title="Volume"
              />
            </div>
          </div>
        </div>

        {playlist.length > 0 && (
          <div className="mt-4 border-t pt-4 dark:border-gray-700">
            <div className="text-sm font-medium mb-2 dark:text-gray-300">Liste de lecture</div>
            <div className="space-y-1 max-h-48 overflow-y-auto">
              {playlist.map((track, index) => (
                <button
                  key={track.path}
                  onClick={() => {
                    handlers.setCurrentTrack(track);
                    if (!isPlaying) handlers.handlePlayPause();
                  }}
                  className={`w-full text-left px-3 py-2 rounded-lg text-sm hover:bg-gray-100 dark:hover:bg-gray-700
                    ${currentTrack.path === track.path ? 'bg-blue-100 dark:bg-blue-900' : ''}`}
                >
                  <div className="font-medium dark:text-white">{track.name}</div>
                </button>
              ))}
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default MediaPlayerUI;